@@ -1392,13 +1392,14 @@ dsc_parse_bounding_box(CDSC *dsc, CDSCBBOX** pbbox, int offset)
 		    fury = dsc_get_real(dsc->line+n, dsc->line_length-n, &i);
 		if (i) {
 		    *pbbox = (CDSCBBOX *)dsc_memalloc(dsc, sizeof(CDSCBBOX));
-		    if (*pbbox == NULL)
-			return CDSC_ERROR;	/* no memory */
-			(*pbbox)->llx = (int)fllx;
-			(*pbbox)->lly = (int)flly;
-			(*pbbox)->urx = (int)(furx+0.999);
-			(*pbbox)->ury = (int)(fury+0.999);
-		}
+                    if (*pbbox == NULL) {
+                        return CDSC_ERROR;	/* no memory */
+                    }
+                    (*pbbox)->llx = (int)fllx;
+                    (*pbbox)->lly = (int)flly;
+                    (*pbbox)->urx = (int)(furx+0.999);
+                    (*pbbox)->ury = (int)(fury+0.999);
+                }
 		return CDSC_OK;
 	    case CDSC_RESPONSE_CANCEL:
 		return CDSC_OK;
